package com.jz.dm.mall.moduls.service.impl;

import com.jz.common.entity.Department;
import com.jz.dm.mall.moduls.entity.FinanceCustomerAssets;
import com.jz.dm.mall.moduls.entity.MallCustomer;
import com.jz.common.utils.Result;
import com.jz.dm.mall.moduls.controller.company.bean.CompanyAddReq;
import com.jz.dm.mall.moduls.mapper.DepartmentDao;
import com.jz.dm.mall.moduls.mapper.FinanceCustomerAssetsDao;
import com.jz.dm.mall.moduls.mapper.MallCustomerDao;
import com.jz.dm.mall.moduls.service.CompanyAuthService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;

/**
 * @author ZC
 * @PACKAGE_NAME: com.jz.dm.mall.moduls.service.impl
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: CompanyAuthServiceImpl
 * @USER: key
 * @DATE: 2020-12-2/16:35
 * @DAY_NAME_SHORT: 周三
 * @Description:
 **/
@Service("companyAuthService")
@Slf4j
public class CompanyAuthServiceImpl implements CompanyAuthService {

    @Resource
    private DepartmentDao departmentDao;
    @Resource
    private FinanceCustomerAssetsDao financeCustomerAssetsDao;
    @Resource
    private MallCustomerDao mallCustomerDao;
    /**
     * 添加企业认证
     *
     * @param req
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class,propagation = Propagation.REQUIRES_NEW)
    public Result addCompanyData(CompanyAddReq req) {
        //TODO 获取当前用户ID判断当前用户是否已经关联企业
       // Long customerId = (Long) UserContextUtil.pop("customer_id");
        Long customerId = 0L;
        if (null ==customerId){
            return Result.error("获取用户信息失败");
        }
        MallCustomer mallCustomer =  mallCustomerDao.findById(customerId);
        if (null == mallCustomer){
            return Result.error("用户信息不存在");
        }
        if (null != mallCustomer.getDepartmentId()){
            return Result.error("用户已关联企业,请勿重复操作");
        }
        req.setCustomerId(mallCustomer.getCustomerId());
        if (StringUtils.isNotBlank(req.getDepartmentName()) &&
                StringUtils.isNotBlank(req.getUnifiedCreditCode())) { //企业名称 && 营业执照
            Department department = departmentDao.selectDepartmentData(req);
            if (null != department) {
                return Result.error("企业用户信息已存在");
            }
        }
        insetCompany(req);
        return Result.ok("添加企业用户成功");
    }

    /**
     * 查询企业认证详情
     * @param type
     * @return
     */
    @Override
    public Result<Department> selectCompany(String type) {
       //查询用户判断用户是否认证
       // Long customerId = (Long) UserContextUtil.pop("customer_id");
       // if (null ==customerId){
       //     return Result.error("获取用户信息失败");
       // }
       // MallCustomer mallCustomer =  mallCustomerDao.findById(customerId);
       // if (null == mallCustomer){
       //     return Result.error("用户信息不存在");
       // }
        return null;
    }

    /**
     * 保存企业信息
     * @param req
     */
    private void insetCompany(CompanyAddReq req) {
        //保存企业信息
        Department departmentInset = new Department();
        departmentInset.setAuditStatus("01");//待审核
        departmentInset.setCreTime(new Date());
        departmentInset.setCrePerson(req.getLoginName());
        BeanUtils.copyProperties(req,departmentInset);
        if (departmentDao.insert(departmentInset) != 1){
            throw new RuntimeException("保存企业信息失败");
        }
        //初始化用户资产表
        FinanceCustomerAssets finance = new FinanceCustomerAssets();
        finance.setDepartmentId(departmentInset.getDepartmentId());//企业ID
        finance.setCreTime(new Date());
        finance.setCrePerson(req.getLoginName());
        if (financeCustomerAssetsDao.insert(finance) != 1){
            throw new RuntimeException("初始化用户资产失败");
        }
        //更新用户企业信息
        MallCustomer mallCustomer = new MallCustomer();
        mallCustomer.setCustomerId(req.getCustomerId());//用户ID
        mallCustomer.setDepartmentId(departmentInset.getDepartmentId());
        mallCustomer.setUptTime(new Date());
       // mallCustomer.setUptPerson(req.getLoginName());
        if (mallCustomerDao.updateById(mallCustomer) != 1){
            throw new RuntimeException("更新用户企业信息失败");
        }
    }
}
